==> haskell-spoon-0.3.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-spoon.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 spoon
version:              0.3.1
visibility:           public
id:                   spoon-0.3.1-4f8DVr5dNtS1qeEtbYFFlu
key:                  spoon-0.3.1-4f8DVr5dNtS1qeEtbYFFlu
license:              BSD-3-Clause
copyright:            2009 Matt Morrow & Dan Peebles, 2013 Liyang HU
maintainer:           Liyang HU <spoon@liyang.hu>
author:               Matt Morrow, Dan Peebles, Liyang HU
stability:            experimental
synopsis:             Catch errors thrown from pure computations.
description:
    Takes an error-throwing expression and puts it back in the Maybe it belongs in.

category:             Error handling
abi:                  7588835fc634df62f8cea909174ca083
exposed:              True
exposed-modules:      Control.Spoon
import-dirs:          /usr/lib/ghc-8.8.3/site-local/spoon-0.3.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/spoon-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/spoon-0.3.1
hs-libraries:         HSspoon-0.3.1-4f8DVr5dNtS1qeEtbYFFlu
depends:              base-4.13.0.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-spoon/html/spoon.haddock
haddock-html:         /usr/share/doc/haskell-spoon/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-spoon-0.3.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-spoon.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 spoon
version:              0.3.1
visibility:           public
id:                   spoon-0.3.1-JoM99BVV06cDTiQOxbX3Q4
key:                  spoon-0.3.1-JoM99BVV06cDTiQOxbX3Q4
license:              BSD-3-Clause
copyright:            2009 Matt Morrow & Dan Peebles, 2013 Liyang HU
maintainer:           Liyang HU <spoon@liyang.hu>
author:               Matt Morrow, Dan Peebles, Liyang HU
stability:            experimental
synopsis:             Catch errors thrown from pure computations.
description:
    Takes an error-throwing expression and puts it back in the Maybe it belongs in.

category:             Error handling
abi:                  ecddc483c67b346c8532175332f844bf
exposed:              True
exposed-modules:      Control.Spoon
import-dirs:          /usr/lib/ghc-8.10.1/site-local/spoon-0.3.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/spoon-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/spoon-0.3.1
hs-libraries:         HSspoon-0.3.1-JoM99BVV06cDTiQOxbX3Q4
depends:              base-4.14.0.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-spoon/html/spoon.haddock
haddock-html:         /usr/share/doc/haskell-spoon/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
